@@ -577,15 +577,15 @@ class SequenceManipMethods():
         Parameters
         ----------
         seqfile : sequence file
-            DESCRIPTION.
-        min_codons : TYPE, optional
-            DESCRIPTION. The default is 80.
-        add_tag : TYPE, optional
-            DESCRIPTION. The default is True.
+            a file containting sequence data to get a mRNA sequence out of.
+        min_codons : iny, optional
+            minimum contingous codons to consider an ORF. The default is 80.
+        add_tag : bool, optional
+            Add a fluorescent tag if none is found. The default is True.
 
         Returns
         -------
-        None.
+        POI obj.
 
         '''
         fp = FileParser.FileParser()
@@ -597,13 +597,13 @@ class SequenceManipMethods():
         
         sizes = [[len(y) for y in x] for x in protein_strs.values()]
         maxsize = max([item for sublist in sizes for item in sublist])
-        
+
         for i in range(3):
             if maxsize in sizes[i]:
                 frame = i
                 pindex = sizes[i].index(maxsize)
                 
-        return proteins[str(int(i)+1)][pindex]
+        return proteins[str(int(i))][pindex]
 
 
     def open_seq_file(self, seqfile, min_codons=80, add_tag=True):
@@ -620,14 +620,42 @@ class SequenceManipMethods():
         #TODO expose this to the user:
         #sequence_name = fp.get_name(seqfile)
         #sequence_description = fp.get_description(seqfile)
-        sequence_str = fp.get_sequence(seqfile).upper()
+        
+        sequence_str = fp.get_sequence(seqfile)
+        if isinstance(sequence_str, str):
+            sequence_str = sequence_str.upper()
+            orfs = self.get_orfs(sequence_str, min_codons=min_codons)
+    
+            protein_strs, proteins, tagged_proteins = self.get_proteins(orfs,
+                                                                        sequence_str,
+                                                                        add_tag=add_tag)
+        if isinstance(sequence_str, list):
+            
+            #multiple sequence fasta detected, split them up and handle them 
+            #seperately, then merge them into the dictionaries later
+            ps_list = []
+            pro_list = []
+            tagd_list = []
+            for sequence in sequence_str:
+                sequence = sequence.upper()
+                orfs = self.get_orfs(sequence, min_codons=min_codons)
+                
+                protein_strs, proteins, tagged_proteins = self.get_proteins(orfs,
+                                                                            sequence,
+                                                                            add_tag=add_tag)
+                ps_list.append(protein_strs)
+                pro_list.append(proteins)
+                tagd_list.append(tagged_proteins)
+                
+            # compress the dictionaries by keys
+            flatten_dict = lambda dictionary: [[item for sublist in [y[x] for y in dictionary]
+                                                for item in sublist] for x in ['1','2','3']]
+            
 
-
-        orfs = self.get_orfs(sequence_str, min_codons=min_codons)
-
-        protein_strs, proteins, tagged_proteins = self.get_proteins(orfs,
-                                                                    sequence_str,
-                                                                    add_tag=add_tag)
+            protein_strs = {i: flatten_dict(ps_list)[int(i)-1] for i in ['1','2','3']}
+            proteins = {i: flatten_dict(pro_list)[int(i)-1] for i in ['1','2','3']}
+            tagged_proteins = {i: flatten_dict(tagd_list)[int(i)-1] for i in ['1','2','3']}
+                
         return protein_strs, proteins, tagged_proteins, sequence_str
 
 
